@@ -1,13 +1,16 @@
+mod interval;
 mod literal;
 mod row;
-pub mod schema;
 mod table;
+
+pub mod schema;
 pub mod value;
 
 pub use {
+    interval::{Interval, IntervalError},
     literal::{Literal, LiteralError},
     row::{Row, RowError},
-    schema::Schema,
+    schema::{Schema, SchemaIndex, SchemaIndexOrd},
     table::{get_name, Table, TableError},
     value::{Value, ValueError},
 };
