@@ -1,12 +1,27 @@
 use {
+    crate::ast::{ColumnDef, ColumnOption, ColumnOptionDef, Expr},
     serde::{Deserialize, Serialize},
-    sqlparser::ast::{ColumnDef, ColumnOption, ColumnOptionDef, Expr},
 };
 
+#[derive(Clone, Copy, Serialize, Deserialize)]
+pub enum SchemaIndexOrd {
+    Asc,
+    Desc,
+    Both,
+}
+
+#[derive(Clone, Serialize, Deserialize)]
+pub struct SchemaIndex {
+    pub name: String,
+    pub expr: Expr,
+    pub order: SchemaIndexOrd,
+}
+
 #[derive(Clone, Serialize, Deserialize)]
 pub struct Schema {
     pub table_name: String,
     pub column_defs: Vec<ColumnDef>,
+    pub indexes: Vec<SchemaIndex>,
 }
 
 pub trait ColumnDefExt {
