@@ -1,35 +1,35 @@
-use serde::Serialize;
-use std::fmt::Debug;
-use thiserror::Error;
-
-use sqlparser::ast::{ObjectName, TableAlias, TableFactor};
-
-use crate::result::Result;
+use {
+    crate::{
+        ast::{IndexItem, ObjectName, TableAlias, TableFactor},
+        result::Result,
+    },
+    serde::Serialize,
+    std::fmt::Debug,
+    thiserror::Error,
+};
 
 #[derive(Error, Serialize, Debug, PartialEq)]
 pub enum TableError {
     #[error("unreachable")]
     Unreachable,
-
-    #[error("TableFactorNotSupported")]
-    TableFactorNotSupported,
 }
 
 pub struct Table<'a> {
     name: &'a String,
     alias: Option<&'a String>,
+    index: Option<&'a IndexItem>,
 }
 
 impl<'a> Table<'a> {
     pub fn new(table_factor: &'a TableFactor) -> Result<Self> {
         match table_factor {
-            TableFactor::Table { name, alias, .. } => {
+            TableFactor::Table { name, alias, index } => {
                 let name = get_name(name)?;
-                let alias = alias.as_ref().map(|TableAlias { name, .. }| &name.value);
+                let alias = alias.as_ref().map(|TableAlias { name, .. }| name);
+                let index = index.as_ref();
 
-                Ok(Self { name, alias })
+                Ok(Self { name, alias, index })
             }
-            _ => Err(TableError::TableFactorNotSupported.into()),
         }
     }
 
@@ -43,13 +43,14 @@ impl<'a> Table<'a> {
             None => self.name,
         }
     }
+
+    pub fn get_index(&self) -> Option<&'a IndexItem> {
+        self.index
+    }
 }
 
 pub fn get_name(table_name: &ObjectName) -> Result<&String> {
     let ObjectName(idents) = table_name;
 
-    idents
-        .last()
-        .map(|ident| &ident.value)
-        .ok_or_else(|| TableError::Unreachable.into())
+    idents.last().ok_or_else(|| TableError::Unreachable.into())
 }
