@@ -1,6 +1,9 @@
-use serde::Serialize;
-use std::fmt::Debug;
-use thiserror::Error;
+use {
+    crate::ast::{Aggregate, Expr},
+    serde::Serialize,
+    std::fmt::Debug,
+    thiserror::Error,
+};
 
 #[derive(Error, Serialize, Debug, PartialEq)]
 pub enum EvaluateError {
@@ -10,9 +13,6 @@ pub enum EvaluateError {
     #[error("literal add on non-numeric")]
     LiteralAddOnNonNumeric,
 
-    #[error("function is not supported: {0}")]
-    FunctionNotSupported(String),
-
     #[error("function requires string value: {0}")]
     FunctionRequiresStringValue(String),
 
@@ -22,26 +22,24 @@ pub enum EvaluateError {
     #[error("function requires usize value: {0}")]
     FunctionRequiresUSizeValue(String),
 
-    #[error(
-        "number of function parameters not matching (expected: {expected:?}, found: {found:?})"
-    )]
-    NumberOfFunctionParamsNotMatching { expected: usize, found: usize },
-
     #[error("value not found: {0}")]
     ValueNotFound(String),
 
     #[error("only boolean value is accepted: {0}")]
     BooleanTypeRequired(String),
 
-    #[error("unsupported compound identifier {0}")]
-    UnsupportedCompoundIdentifier(String),
+    #[error("unsupported compound identifier {0:#?}")]
+    UnsupportedCompoundIdentifier(Expr),
 
-    #[error("unimplemented")]
-    Unimplemented,
+    #[error("unsupported stateless expression: {0:#?}")]
+    UnsupportedStatelessExpr(Expr),
+
+    #[error("unreachable wildcard expression")]
+    UnreachableWildcardExpr,
 
     #[error("unreachable empty context")]
     UnreachableEmptyContext,
 
-    #[error("unreachable named function argument: {0}")]
-    UnreachableFunctionArg(String),
+    #[error("unreachable empty aggregate value: {0:?}")]
+    UnreachableEmptyAggregateValue(Aggregate),
 }
