@@ -1,6 +1,5 @@
 mod aggregate;
 mod alter;
-mod blend;
 mod context;
 mod evaluate;
 mod execute;
@@ -9,17 +8,15 @@ mod filter;
 mod join;
 mod limit;
 mod select;
+mod sort;
 mod update;
 mod validate;
 
 pub use aggregate::{AggregateError, GroupKey};
 pub use alter::AlterError;
-pub use blend::BlendError;
-pub use evaluate::EvaluateError;
+pub use evaluate::{evaluate_stateless, EvaluateError};
 pub use execute::{execute, ExecuteError, Payload};
 pub use fetch::FetchError;
-pub use join::JoinError;
-pub use limit::LimitError;
 pub use select::SelectError;
 pub use update::UpdateError;
 pub use validate::{UniqueKey, ValidateError};
