@@ -20,6 +20,7 @@
 //!     let mut glue = Glue::new(storage);
 //!
 //!     let sqls = "
+//!         DROP TABLE IF EXISTS Glue;
 //!         CREATE TABLE Glue (id INTEGER);
 //!         INSERT INTO Glue VALUES (100);
 //!         INSERT INTO Glue VALUES (200);
@@ -27,9 +28,7 @@
 //!         DROP TABLE Glue;
 //!     ";
 //!
-//!     for query in parse(sqls).unwrap() {
-//!         glue.execute(&query).unwrap();
-//!     }
+//!     glue.execute(&sqls).unwrap();
 //! }
 //!
 //! #[cfg(not(feature = "sled-storage"))]
@@ -37,23 +36,27 @@
 //! ```
 //!
 //! ## Custom Storage
-//! All you need to implement for `gluesql` is implementing 3 traits (2 for functions, 1 for
-//! running tests).
-//! There is also an optional trait (AlterTable), whether implementing it or not is all up to you.
+//! To get started, all you need to implement for `gluesql` is implementing three traits
+//! (two for functions, one running tests).
+//! There are also three optional traits (`AlterTable`, `Index` and `IndexMut`),
+//! whether implementing it or not is all up to you.
 //!
+//! ### Store traits
 //! * [Store](store/trait.Store.html)
 //! * [StoreMut](store/trait.StoreMut.html)
-//! * [AlterTable - optional](store/trait.AlterTable.html)
+//!
+//! ### Store traits (optional)
+//! * [AlterTable](store/trait.AlterTable.html)
+//! * [Index](store/trait.Index.html)
+//! * [IndexMut](store/trait.IndexMut.html)
+//!
+//! ### Trait to run integration tests
 //! * [Tester](tests/trait.Tester.html)
 //!
-//! Custom storage examples to see,
-//! * [GlueSQL-js](https://github.com/gluesql/gluesql-js)
-//!
 //! ## Tests
-//! For making easy for developers to implement custom storages, `gluesql` also provides integration
-//! tests as a module.
-//!
-//! So, in `/tests/`, it looks quite empty, but actual test cases exist in `src/tests/`.
+//! `gluesql` provides integration tests as a module.
+//! Developers who wants to make their own custom storages can import and run those tests.
+//! `/tests/` might look quite empty, but actual test cases exist in `src/tests/`.
 //!
 //! Example code to see,
 //! * [tests/sled_storage.rs](https://github.com/gluesql/gluesql/blob/main/tests/sled_storage.rs)
@@ -61,6 +64,7 @@
 //! After you implement `Tester` trait, the only thing you need to do is calling `generate_tests!` macro.
 
 // re-export
+pub use chrono;
 pub use sqlparser as parser;
 
 mod executor;
@@ -69,16 +73,21 @@ mod parse_sql;
 mod storages;
 mod utils;
 
+pub mod ast;
 pub mod data;
+pub mod plan;
 pub mod result;
 pub mod store;
 pub mod tests;
+pub mod translate;
 
 pub use data::*;
 pub use executor::*;
 pub use parse_sql::*;
+pub use plan::*;
 pub use result::*;
 pub use store::*;
+pub use translate::*;
 
 #[cfg(feature = "sled-storage")]
 pub use glue::Glue;
