@@ -1,15 +1,20 @@
 mod alter_table;
 mod error;
+mod index;
+mod index_mut;
+mod index_sync;
 mod store;
 mod store_mut;
-#[cfg(not(feature = "alter-table"))]
-impl crate::AlterTable for SledStorage {}
 
-use sled::{self, Config, Db};
-use std::convert::TryFrom;
-
-use crate::{Error, Result, Schema};
-use error::err_into;
+use {
+    crate::{
+        store::{GStore, GStoreMut},
+        Error, Result, RowIter, Schema,
+    },
+    error::err_into,
+    sled::{self, Config, Db, IVec},
+    std::convert::TryFrom,
+};
 
 #[derive(Debug, Clone)]
 pub struct SledStorage {
@@ -44,3 +49,19 @@ fn fetch_schema(tree: &Db, table_name: &str) -> Result<(String, Option<Schema>)>
 
     Ok((key, schema))
 }
+
+fn scan_data(tree: &Db, table_name: &str) -> RowIter<IVec> {
+    let prefix = format!("data/{}/", table_name);
+
+    let result_set = tree.scan_prefix(prefix.as_bytes()).map(move |item| {
+        let (key, value) = item.map_err(err_into)?;
+        let value = bincode::deserialize(&value).map_err(err_into)?;
+
+        Ok((key, value))
+    });
+
+    Box::new(result_set)
+}
+
+impl GStore<IVec> for SledStorage {}
+impl GStoreMut<IVec> for SledStorage {}
