@@ -21,6 +21,35 @@ impl<T> Vector<T> {
         self
     }
 
+    #[cfg(all(feature = "index", feature = "sled-storage"))]
+    pub fn remove(mut self, i: usize) -> Self {
+        self.0.remove(i);
+
+        self
+    }
+
+    #[cfg(all(feature = "index", feature = "sled-storage"))]
+    pub fn reverse(mut self) -> Self {
+        self.0.reverse();
+
+        self
+    }
+
+    pub fn sort_by<F>(mut self, compare: F) -> Self
+    where
+        F: FnMut(&T, &T) -> std::cmp::Ordering,
+    {
+        self.0.sort_by(compare);
+
+        self
+    }
+
+    pub fn pop(mut self) -> (Self, Option<T>) {
+        let v = self.0.pop();
+
+        (self, v)
+    }
+
     pub fn get(&self, i: usize) -> Option<&T> {
         self.0.get(i)
     }
