@@ -3,7 +3,7 @@
 use sled::IVec;
 use std::{cell::RefCell, convert::TryFrom, rc::Rc};
 
-use gluesql::{generate_alter_table_tests, generate_tests, sled, tests::*, SledStorage};
+use gluesql::{generate_tests, sled, tests::*, SledStorage};
 
 struct SledTester {
     storage: Rc<RefCell<Option<SledStorage>>>,
